#!/usr/bin/env python

from distutils.core import setup

setup(name='cnn_colorflow',
      version='0.1',
      description='A series of useful functions developed during the writing of "Identifying the Quantum Properties of Hadronic Resonances using Machine Learning"',
      author='John Kruper',
      author_email='jk6.28@outlook.com')
